@@ -1069,6 +1069,41 @@ public:
 	 */
 	static ssize_t sendto(socket_t socket, const void *buffer, size_t size, int flags = 0, struct sockaddr *address = NULL);
 
+	/**
+	 * Send reply on socket.  Used to reply to a recvfrom message.
+	 * @param socket to send to.
+	 * @param buffer to send.
+	 * @param size of data buffer to send.
+	 * @param flags for i/o operation (MSG_OOB, MSG_PEEK, etc).
+	 * @param address to reply to.
+	 * @return number of bytes sent, -1 if error.
+	 */
+	inline static ssize_t replyto(socket_t socket, const void *buffer, size_t size, int flags, struct sockaddr_storage *address)
+		{return sendto(socket, buffer, size, flags, (struct sockaddr *)address);};
+
+	/**
+	 * Send to internet socket.  
+	 * @param socket to send to.
+	 * @param buffer to send.
+	 * @param size of data buffer to send.
+	 * @param flags for i/o operation (MSG_OOB, MSG_PEEK, etc).
+	 * @param address to send to.
+	 * @return number of bytes sent, -1 if error.
+	 */
+	inline static ssize_t sendinet(socket_t socket, const void *buffer, size_t size, int flags, struct sockaddr_internet *address)
+		{return sendto(socket, buffer, size, flags, (struct sockaddr *)address);};
+
+	/**
+	 * Get internet data waiting in receive queue.
+	 * @param socket to get from.
+	 * @param buffer to save.
+	 * @param size of data buffer to request.
+	 * @param flags for i/o operation (MSG_OOB, MSG_PEEK, etc).
+	 * @param internet address of source.
+	 * @return number of bytes received, -1 if error.
+	 */
+	static ssize_t recvinet(socket_t socket, void *buffer, size_t size, int flags = 0, struct sockaddr_internet *address = NULL);
+
 	/**
 	 * Bind the socket descriptor to a known interface and service port.
 	 * @param socket descriptor to bind.
@@ -1166,7 +1201,7 @@ public:
 	 * @param address list to connect to.
 	 */
 	inline static void connectto(Socket& socket, Socket::address &address)
-		{socket.connectto(socket, address);};
+		{socket.connectto(address);};
 
 	/**
 	 * Disconnect a connected socket.
@@ -1221,14 +1256,6 @@ public:
 	 */
 	static socklen_t getlen(struct sockaddr *address);
 
-	/**
-	 * Copy a socket address from one structure to another.  The size of
-	 * the address is determined by getlen.
-	 * @param from address of original.
-	 * @param to address to save.
-	 */
-	static void copy(struct sockaddr *from, struct sockaddr *to);
-
 	/**
 	 * Compare socket addresses.  Test if the address and service matches
 	 * or if there is no service, then just the host address values.
@@ -1238,6 +1265,31 @@ public:
 	 */
 	static bool equal(struct sockaddr *address1, struct sockaddr *address2);
 
+	/**
+	 * Copy a socket address.
+	 * @param target address pointer to copy into.
+	 * @param source address pointer to copy from.
+	 * @return number of bytes copied, 0 if invalid.
+	 */
+	static unsigned copy(struct sockaddr *target, struct sockaddr *from);
+
+	/**
+	 * Store an address into an address object.
+	 * @param storage for address.
+	 * @param address to store.
+	 * @return number of bytes stored.
+	 */
+	inline static unsigned store(struct sockaddr_storage *storage, struct sockaddr *address)
+		{return copy((struct sockaddr*)storage, address);};
+
+	/**
+	 * Store an address into an internet address object.
+	 * @param storage for address.
+	 * @param address to store.
+	 * @return number of bytes stored.
+	 */
+	static unsigned store(struct sockaddr_internet *storage, struct sockaddr *address);
+
 	/**
 	 * Compare socket host addresses.  Test if the host addressmatches
 	 * or if there is no service, then just the host address values.
@@ -1247,6 +1299,25 @@ public:
 	 */
 	static bool equalhost(struct sockaddr *address1, struct sockaddr *address2);
 
+	/**
+	 * Compare socket addresses.  Test if the stored addresses received match.
+	 * or if there is no service, then just the host address values.
+	 * @param address1 to compare.
+	 * @param address2 to compare.
+	 * @return true if same family and equal.
+	 */
+	inline static bool equalfrom(struct sockaddr_storage *address1, struct sockaddr_storage *address2)
+		{return equal((struct sockaddr *)address1, (struct sockaddr *)address2);};
+
+	/**
+	 * Compare socket addresses.  Test if the internet addresses received match.
+	 * or if there is no service, then just the host address values.
+	 * @param address1 to compare.
+	 * @param address2 to compare.
+	 * @return true if same family and equal.
+	 */
+	inline static bool equalinet(struct sockaddr_internet *address1, struct sockaddr_internet *address2)
+		{return equal((struct sockaddr *)address1, (struct sockaddr *)address2);};
 
 	/**
 	 * See if both addresses are in the same subnet.  This is only relevent
@@ -1282,6 +1353,14 @@ public:
 	 */
 	static short getservice(struct sockaddr *address);
 
+	/**
+	 * Get the service port of an inet socket.
+	 * @param address of internet socket to examine.
+	 * @return service port number.
+	 */
+	inline static short inetservice(struct sockaddr_internet *address)
+		{return getservice((struct sockaddr *)address);};
+
 	/**
 	 * Convert a socket address and service into a hash map index.
 	 * @param address to convert.
@@ -1298,7 +1377,6 @@ public:
 	 */
 	static unsigned keyhost(struct sockaddr *address, unsigned size);
 
-
 	/**
 	 * Initialize socket subsystem.
 	 */
